@@ -73,6 +73,20 @@ def test_can_repair_inversions(mesh):
     Volume(mesh.points, triangles, True)
 
 
+@pytest.mark.skipif(not trimesh, reason="Requires trimesh")
+def test_inversions_repaired(simple_mesh):
+    center = [0.5, 0.5, 0.5]
+
+    orig_points = simple_mesh.points
+    orig_triangles = simple_mesh.cells["triangle"]
+    assert center in Volume(orig_points, orig_triangles)
+
+    inv_triangles = orig_triangles[:, ::-1]
+    assert center not in Volume(orig_points, inv_triangles)
+
+    assert center in Volume(orig_points, inv_triangles, validate=True)
+
+
 def test_points(mesh):
     points = mesh.points
     vol = Volume(mesh.points, mesh.cells["triangle"])
